/**
 * @packageDocumentation
 * @module String
 */
import { OperatorFunction, Subscribable } from 'rxjs';
/**
 * Returns an Observable that emits an array of numbers. The number is returned from String.codePointAt using the passed
 * index or array of indexes.  The output is always an `Array` containing the number, or `NaN`.
 *
 * @category Query
 *
 * @remarks By default String.codePointAt returns undefined, this operator returns `NaN` instead matching [[charCodeAt]]
 *
 * @param positions Single or list of index values to return the character at
 *
 * @example
 * Return the code point of the character at index `1`
 * ```ts
 * of('☃★♲').pipe(codePointAt(1)).subscribe();
 * ```
 * Output: `9733`
 *
 * @returns Observable that emits a number that is a code point
 */
export declare function codePointAt(positions: Subscribable<Iterable<number> | number> | Iterable<number> | number): OperatorFunction<string, number[]>;
